#[derive(Debug, PartialEq)]
enum ImageType {
    Jpeg,
    Png,
    Gif,
    WebP,
    AnimatedWebP,
    Unsupported,
}

// fn process_image(file_path_string: String) -> Result<String, String> {
//     // convert string to path to use in rust
//     let file_path = std::path::Path::new(&file_path_string);

//     // get the data directory path
//     let data_dir = tauri::api::path::data_dir().ok_or("Failed to get data directory")?;
//     let mut destination = data_dir.clone();
//     // we can hardcode the file name since
//     // 1. we are only dealing with one wallpaper image at a time
//     // 2. we will be converting all images to the webp format
//     destination.push("wallpaper.webp");

//     // determine the file format
// }

// fn determine_image_type(file_path: &std::path::Path) -> Result<ImageType, String> {
//     // open the file
//     let mut file =
//         std::fs::File::open(file_path).map_err(|e| format!("Failed to open file: {e}"))?;

//     // read the first few bytes to determine the format
//     let mut buffer = [0; 12];
//     file.read_exact(&mut buffer)
//         .map_err(|e| format!("Failed to read file: {e}"))?;

//     // check statis formats
//     if let Some(format) = image::guess_format(&buffer).ok() {
//         match format {
//             image::ImageFormat::Jpeg => return Ok(ImageType::Jpeg),
//             image::ImageFormat::Png => return Ok(ImageType::Png),
//             image::ImageFormat::Gif => return Ok(ImageType::Gif),
//             image::ImageFormat::WebP => {
//                 // additional check if is animated
//                 if is_animated_webp(file_path) {
//                     return Ok(ImageType::AnimatedWebP);
//                 } else {
//                     return Ok(ImageType::WebP);
//                 }
//             }
//             _ => return Ok(ImageType::Unsupported),
//         }
//     } else {
//         return Ok(ImageType::Unsupported);
//     }
// }

/// check if the file is a valid webp image and if it is animated
/// returns `Ok(true)` if it is animated, `Ok(false)` if it is not
/// and errors out if the file cannot be read or is not a webp
fn is_animated_webp(file_path: &std::path::Path) -> Result<bool, String> {
    // open the file and read its contents into a buffer
    let mut buffer = Vec::new();
    std::fs::File::open(file_path)
        .and_then(|mut file| std::io::Read::read_to_end(&mut file, &mut buffer))
        .map_err(|e| format!("Failed to read file: {}", e))?;

    // use the webp crate to decode the image and check for animation
    webp::AnimDecoder::new(&buffer)
        .decode()
        .map(|anim| anim.has_animation())
        .map_err(|_| "File is not a valid WebP image".to_string())
}

fn main() {
    // Example usage
    let path = std::path::Path::new("/home/vomitblood/Downloads/Win10_22H2_English_x64v1.iso");
    match is_animated_webp(path) {
        Ok(true) => println!("The WebP is animated."),
        Ok(false) => println!("The WebP is not animated."),
        Err(e) => println!("Error: {}", e),
    }
}
